@@ -1,11 +1,14 @@
 package App::DumpChromeHistory;
 
-our $DATE = '2019-08-14'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-04-18'; # DATE
+our $DIST = 'App-DumpChromeHistory'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
+use Log::ger;
 
 our %SPEC;
 
@@ -85,13 +88,18 @@ sub dump_chrome_history {
             }
         };
         my $err = $@;
-        if ($err && $err =~ /database is locked/ && (-s $hist_path) <= $args{copy_size_limit}) {
-            require File::Copy;
-            require File::Temp;
-            my ($temp_fh, $temp_path) = File::Temp::tempfile();
-            File::Copy::copy($hist_path, $temp_path) or die $err;
-            $hist_path = $temp_path;
-            redo SELECT;
+        if ($err && $err =~ /database is locked/) {
+            if ((-s $hist_path) <= $args{copy_size_limit}) {
+                log_debug "Database is locked ($err), will try to copy and query the copy instead ...";
+                require File::Copy;
+                require File::Temp;
+                my ($temp_fh, $temp_path) = File::Temp::tempfile();
+                File::Copy::copy($hist_path, $temp_path) or die $err;
+                $hist_path = $temp_path;
+                redo SELECT;
+            } else {
+                log_debug "Database is locked ($err) but is too big, will wait instead";
+            }
         }
     }
 
@@ -115,7 +123,7 @@ App::DumpChromeHistory - Dump Chrome history
 
 =head1 VERSION
 
-This document describes version 0.002 of App::DumpChromeHistory (from Perl distribution App-DumpChromeHistory), released on 2019-08-14.
+This document describes version 0.003 of App::DumpChromeHistory (from Perl distribution App-DumpChromeHistory), released on 2020-04-18.
 
 =head1 SYNOPSIS
 
@@ -155,6 +163,7 @@ You can either provide a name, e.g. C<Default>, the profile directory of which
 will be then be searched in C<< ~/.config/google-chrome/E<lt>nameE<gt> >>. Or you can also
 provide a directory name.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -196,7 +205,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
